@@ -18,21 +18,14 @@ use Data::Tools;
 use Data::Dumper;
 use Exception::Sink;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 ##############################################################################
 
-=pod
-
-minimum config:
-
-my %cfg = (
-          '' => ,
-#         '' => ,
-          );
-
-
-=cut
+#minimum config:
+#my %cfg = (
+#          '' => ,
+#          );
 
 our @HTTP_VARS_CHECK = qw(
                            REMOTE_ADDR
@@ -553,27 +546,6 @@ sub __make_headers
 
 ##############################################################################
 
-=pod
-sub __update_session_data_sha1
-{
-  my $self = shift;
-
-  my $mod_cache = $self->{ 'CACHE' }{ 'SESSION_DATA_SHA1' } ||= {};
-
-  for my $type ( qw( USER PAGE LINK ) )
-    {
-    while( my ( $sid, $shr ) = each %{ $self->{ 'SESSIONS' }{ 'DATA' }{ $type } } )
-      {
-      $self->boom( "SESSION:DATA:$type:$sid is not hashref" ) unless ref( $shr ) eq 'HASH';
-
-      my $sha1   = sha1_hex( freeze( $shr ) );
-
-      $mod_cache->{ $type }{ $sid } = $sha1;
-      }
-    }
-}
-=cut
-
 sub save
 {
   my $self = shift;
